@@ -5,11 +5,13 @@
 import logging
 
 
-def logger(log_file='log.log'):
+def logger(log_file=None):
     """
     生成logger实例
     :return: logger实例
     """
+    if not log_file:
+        log_file = 'log_by_yucctools.log'
     # create logger with a name
     logger = logging.getLogger()
     if not logger.handlers:
